@@ -1,5 +1,8 @@
 import tensorflow as tf
 import os
+import git
+import tempfile
+import shutil
 
 
 def get_folder_name(path, prefix=''):
@@ -50,3 +53,25 @@ def standardize(tensor, axis=0, return_mean=False):
         return z, mean_value
     else:
         return z
+
+
+
+
+def load_weights(model, git_link , model_name, overwrite=False):
+    
+    # Creating a temporary directory and getting the saved weights
+    model_path = os.path.join(os.getcwd(), model_name)
+    test_dir = tempfile.mkdtemp()
+    git.Repo.clone_from(git_link, test_dir, branch='main', depth=1)
+    if os.path.exists(model_path):
+        if overwrite:
+            os.remove(model_path)
+        else:
+            print("The saved weights already exists")
+    shutil.move(os.path.join(test_dir, model_name), os.getcwd())
+    # shutil.rmtree(test_dir)
+
+    # Loading the model
+    if os.path.exists(model_path):
+        model = model.load_weights(model_path)
+    return model
\ No newline at end of file
